@@ -225,8 +225,7 @@ class Experiment(Jsonable):
     # fluent interface
 
     def copy(self):
-        """Returns a copy of the current experiment object
-        """
+        """Returns a copy of the current experiment object"""
         task = __class__()
         task.specification = self.specification.copy()
         return task
@@ -249,13 +248,19 @@ class Experiment(Jsonable):
         return self
 
     def component(
-        self, name, version=None, checkpoint=None, flags=None, resources=None
+        self,
+        name,
+        version=None,
+        checkpoint=None,
+        flags=None,
+        resources=None,
     ):
         """Adds a component to the experiment
 
         # Arguments
         name: String, the name of the components as defined in the machinable.yaml
         version: dict|String, a configuration update to override its default config
+                 Use '_mixins_' key to override default mixins where `"^"` will be expanded as the default mixin config.
         checkpoint: String, optional URL to a checkpoint file from which the components will be restored
         flags: dict, optional flags to be passed to the component
         resources: dict, specifies the resources that are available to the component.
