@@ -82,19 +82,6 @@ def get(view_type, instance, name=None):
         return None
 
 
-class View:
-    def __init__(self, submission):
-        self.submission = submission
-
-
-class SubmissionView(View):
-    pass
-
-
-class SubmissionComponentView(View):
-    pass
-
-
 class Views:
     @classmethod
     def clear(cls, types=None):
@@ -157,3 +144,27 @@ class Views:
             return _decorate(view)
 
         return _decorate
+
+
+class SubmissionView:
+    register = Views.submission
+
+    def __init__(self, submission):
+        from ..submission import Submission
+
+        self.submission: Submission = Submission.create(submission)
+
+
+class SubmissionComponentView:
+    register = Views.component
+
+    def __init__(self, submission, component: int = 0):
+        from ..submission import Submission
+        from ..component import SubmissionComponent
+
+        if isinstance(submission, SubmissionComponent):
+            self.submission: SubmissionComponent = submission
+        else:
+            self.submission: SubmissionComponent = Submission.find(
+                submission, component=component, or_fail=True
+            )
